#!/bin/bash

SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source clone_sources_utils.sh
source ${SCRIPT_DIR}/../../bash_utils/helpers.sh

# Arguments
INSTALL_NAME=
IFS_BUNDLE_REPO=
IFS_BUNDLE_BRANCH=
GIT_BRANCH=
IFS_BUNDLE_ENV=
REMOTE_DIR=
FORCE=false

# 0. Check args:
parse_args "$@" 
check_required_args 
print_options

# 1. Cloning ifs-bundle to aux and get branch & commit info:
info "Cloning ifs bundle..."
[ -d aux_dir ] && rm -rdf aux_dir
git clone $IFS_BUNDLE_REPO $GIT_BRANCH aux_dir &> /dev/null
REPO_HASH=$(git -C aux_dir rev-parse --short HEAD)
REPO_BRANCH=$(git -C aux_dir rev-parse --abbrev-ref HEAD)
REPO_BRANCH="${REPO_BRANCH//\//.}"
REPO_ID="ifs-bundle-${REPO_BRANCH}-${REPO_HASH}"
[ -z $INSTALL_NAME ] || REPO_ID=$INSTALL_NAME
info "Using $REPO_ID as version"

if [ -d $REPO_ID ]; then
    # Check if this branch is already there -> SKIP CLONE
    info "IFS-BUNDLE VERSION $REPO_ID ALREADY HERE!"
    rm -rdf aux_dir
else
    mv aux_dir $REPO_ID
    success "DONE"
fi

# 2. Apply ifs-bundle env (if required)
[ -z $IFS_BUNDLE_ENV ] || source $IFS_BUNDLE_ENV 
[ -z $IFS_BUNDLE_ENV ] || cp $IFS_BUNDLE_ENV $REPO_ID
echo printenv | grep IFS_BUNDLE

# 4. Build the bundle
info "Creating ifs bundle..."
cd $REPO_ID
./ifs-bundle create -j 8 --shallow
success "DONE"

# 5. Send to remote-dir ?
if [[ -z $REMOTE_DIR ]]; then
    info "No remote dir selected"
else
    info "Sending data to $REMOTE_DIR ..."
    cd ..
    tar czf ${REPO_ID}.tar.gz $REPO_ID 
    rsync ${REPO_ID}.tar.gz $REMOTE_DIR
    success "Data upload to $REMOTE_DIR"
fi

