
source ../../bash_utils/helpers.sh

usage() {
    info "USAGE:"
    info "--repo [--branch] [--bundle-env] [--remote-dir]"
    info "--help [--force] [--name]"
    info "name : Set name for the installation, default: ${REPO-BRANCH}-${COMMIT-HASH}"
    info "force : no ask for sync files"
    info "remote-dir : Path to be used with rsync (remote-host:/your/path/to/submit)"
    info "Don't add the folder name to the remote-dir!" 
}

parse_args() {
    OPTIONS=$(getopt -o "" --long repo:,branch:,bundle-env:,remote-dir:,name:,force,help -n "$0" -- "$@")
    eval set -- "$OPTIONS"

    while true; do
        case "$1" in
            --repo)
                IFS_BUNDLE_REPO="$2"
                shift 2
            ;;
            --branch)
                IFS_BUNDLE_BRANCH="$2"
                GIT_BRANCH="-b $2"
                shift 2
            ;;
            --bundle-env)
                IFS_BUNDLE_ENV=$2
                shift 2
            ;;
            --remote-dir)
                REMOTE_DIR="$2"
                shift 2
            ;;
            --force)
                FORCE=true
                shift
            ;;
            --env)
                ENV_FILE="$2"
                shift 2
            ;;
            --name)
                INSTALL_NAME=$2
                shift 2
            ;;
            --help)
                usage
                exit 0
            ;;
            --)
                shift
                break
            ;;
            *)
                usage
                exit 1
            ;;
        esac
    done
}

check_required_args(){
    [ -z $IFS_BUNDLE_REPO ] && fatal "Must set repo with --repo"
}

print_options(){
    info "===============================IFS-BUNDLE==========================================="
    info "REPO: $IFS_BUNDLE_REPO"
    [ -z "$IFS_BUNDLE_BRANCH" ] && info "BRANCH: Default branch for ifs-bundle"
    [ -z "$IFS_BUNDLE_BRANCH" ] || info "BRANCH: $IFS_BUNDLE_BRANCH"
    [ -z $IFS_BUNDLE_ENV ] && info "IFS-BUNDLE-ENV: NO BUNDLE OVERRIDE" 
    [ -z $IFS_BUNDLE_ENV ] || info "IFS-BUNDLE-ENV: $IFS_BUNDLE_ENV"
    [ -z $REMOTE_DIR ] && info "NO REMOTE DIR SELECTED"
    [ -z $REMOTE_DIR ] || info "REMOTE-DIR: $REMOTE_DIR"
    info "===================================================================================="

    if [ $FORCE = false ]; then
        echo -n "CONTINUE? (Y/N) "
        read ANSWER
        case "$ANSWER" in
            [Yy])
                success "OK"
                ;;
            *)
                fatal "USER INPUT: $ANSWER"
                ;;
        esac
    else
        info "Force ENABLED, skip ask to the user"
    fi
}
